An Ash.Resource.Change that sets an attribute to the plural form of
another attribute.
Options
:attribute(atom, required) — the attribute to write the plural form to:from(atom, required) — the source attribute to read and pluralize
Usage
change {Plurality.Ash.Changes.Pluralize, attribute: :table_name, from: :resource_name}If the source attribute is nil, the changeset is returned unchanged.